@@ -8,6 +8,6 @@ POLL_DELAY = 5
 
 
 @lru_cache(maxsize=None)
-def git_current_branch():
+def git_current_branch() -> str:
     """Get the current git branch."""
     return run("git branch --show-current", hide=True).stdout.strip()
